@@ -193,16 +193,17 @@ class RedizConventions(object):
         return [ w.replace('s','5').replace('l','1') for w in words]
 
     @staticmethod
-    def vanity_key(head=None):
-        head = head or random.choice(RedizConventions.vanity_words())
-        assert all( [c in "0123456789abcdef-" for c in head] ),'Must be a,b,c,d,e,f or digits '
+    def vanity_key(username=None):
+        username = username or random.choice(RedizConventions.vanity_words())
+        username = username.replace('l', '1').replace('s', '5')
+        assert all([c in "0123456789abcdef-" for c in username]), 'Must be a,b,c,d,e,f or digits '
         remaining = 100000
-        print(head)
+        print(username)
         while remaining:
             remaining = remaining-1
             write_key = RedizConventions.random_key()
             code = RedizConventions.hash(write_key)
-            if code[:len(head)]==head:
+            if code[:len(username)]==username:
                 return write_key
 
     @staticmethod
